Enum smithay_client_toolkit::keyboard::Error[][src]

pub enum Error {
    XKBNotFound,
    BadNames,
}

An error that occured while trying to initialize a mapped keyboard

Variants

libxkbcommon is not available

Provided RMLVO sepcified a keymap that would not be loaded