Enum smithay_client_toolkit::output::Transform
source · #[non_exhaustive]#[repr(u32)]pub enum Transform {
Normal,
_90,
_180,
_270,
Flipped,
Flipped90,
Flipped180,
Flipped270,
}Expand description
transform from framebuffer to output
This describes the transform that a compositor will apply to a surface to compensate for the rotation or mirroring of an output device.
The flipped values correspond to an initial flip around a vertical axis followed by rotation.
The purpose is mainly to allow clients to render accordingly and tell the compositor, so that for fullscreen surfaces, the compositor will still be able to scan out directly from client surfaces.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal
no transform
_90
90 degrees counter-clockwise
_180
180 degrees counter-clockwise
_270
270 degrees counter-clockwise
Flipped
180 degree flip around a vertical axis
Flipped90
flip and rotate 90 degrees counter-clockwise
Flipped180
flip and rotate 180 degrees counter-clockwise
Flipped270
flip and rotate 270 degrees counter-clockwise
Implementations