pub struct PrimarySelectionOffer { /* private fields */ }Expand description
A primary selection offer for receiving data through copy/paste.
Implementations
sourceimpl PrimarySelectionOffer
impl PrimarySelectionOffer
sourcepub fn with_mime_types<F, T>(&self, f: F) -> T where
F: FnOnce(&[String]) -> T,
pub fn with_mime_types<F, T>(&self, f: F) -> T where
F: FnOnce(&[String]) -> T,
Access the list of mime types proposed by this offer.