Module input_method

Implementation of the input-method-unstable-v2 protocol.

This protocol allows applications to act as input methods for compositors.

Implementation status

Currently only the input-method object is supported. No keyboard grab, no popup surface.

Structs

InputMethod
InputMethodData
InputMethodEventState
Stores incoming interface state.
InputMethodManager
SurroundingText
ZwpInputMethodV2
input method

Enums

Active
State machine for determining the capabilities of a text input
CursorPosition

Traits

InputMethodDataExt
InputMethodHandler