Enum smithay_client_toolkit::seat::keyboard::RepeatKind[][src]

pub enum RepeatKind {
    Fixed {
        rate: u32,
        delay: u32,
    },
    System,
}
Possible kinds of key repetition

Variants

Fixed

keys will be repeated at a set rate and delay

Fields of Fixed

rate: u32

The number of repetitions per second that should occur.

delay: u32

delay (in milliseconds) between a key press and the start of repetition

System

keys will be repeated at a rate and delay set by the wayland server