Struct smithay_client_toolkit::seat::SeatHandler
source · pub struct SeatHandler { /* private fields */ }Expand description
A simple handler for seats
This handler will manage seats and track their capabilities.
You can register callbacks using the SeatHandling::listen
to be notified whenever a seat is created, destroyed, or its capabilities change.
Implementations
sourceimpl SeatHandler
impl SeatHandler
sourcepub fn new() -> SeatHandler
pub fn new() -> SeatHandler
Create a new SeatHandler