Enum smithay_client_toolkit::shell::Shell [−][src]
Possible supported shell protocols
Variants
The current standard xdg_shell protocol.
Zxdg(Attached<ZxdgShellV6>)A previous iteration of the xdg_shell protocol.
It has been replaced by the stable xdg_shell, and is only present here for
compatibility purposes.
Tuple Fields of Zxdg
0: Attached<ZxdgShellV6>The legacy wl_shell.
It is deprecated and only present here for compatibility purposes.
Implementations
Check if the shell in use needs you to wait for a configure event
before you are allowed to draw.