Struct smithay_client_toolkit::data_device::ReadPipe
source · [−]pub struct ReadPipe { /* private fields */ }Expand description
A file descriptor that can only be read from
If the calloop cargo feature is enabled, this can be used
as an EventSource in a calloop event loop.