Module smithay_client_toolkit::keyboard [−][src]
Utilities for keymap interpretation of keyboard input
This module provides an implementation for wl_keyboard
objects using libxkbcommon to interpret the keyboard input
given the user keymap.
You simply need to provide an implementation to receive the
intepreted events, as described by the Event enum of this modules.
Implementation of you NewProxy<WlKeyboard> can be done with the
map_keyboard_auto or the map_keyboard_rmlvo functions depending
on wether you wish to use the keymap provided by the server or a
specific one.
Modules
| keysyms |
Structs
| ModifiersState |
Represents the current state of the keyboard modifiers |
| RMLVO |
The RMLVO description of a keymap |
Enums
| Error |
An error that occured while trying to initialize a mapped keyboard |
| Event |
Events received from a mapped keyboard |
| KeyState |
physical key state |
Functions
| map_keyboard_auto |
Implement a keyboard to automatically detect the keymap |
| map_keyboard_rmlvo |
Implement a keyboard for a predefined keymap |