pub enum RepeatKind {
Fixed {
rate: u32,
delay: u32,
},
System,
}
Possible kinds of key repetition
keys will be repeated at a set rate and delay
Fields of Fixed
The number of repetitions per second that should occur.
delay (in milliseconds) between a key press and the start of repetition
keys will be repeated at a rate and delay set by the wayland server
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.